@@ -6,7 +6,7 @@
 setClass("AnnotationHub", contains="Hub")
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Constructor 
+### Constructor
 ###
 
 ## Add code to check : https://annotationhub.bioconductor.org/metadata/highest_id
@@ -15,21 +15,22 @@ AnnotationHub <-
     function(..., hub=getAnnotationHubOption("URL"),
              cache=getAnnotationHubOption("CACHE"),
              proxy=getAnnotationHubOption("PROXY"),
-             localHub=getAnnotationHubOption("LOCAL"))
+             localHub=getAnnotationHubOption("LOCAL"),
+             ask=getAnnotationHubOption("ASK"))
 {
     if (is.null(proxy)){
-        connect <- curl::has_internet()
+        connect <- !is.null(curl::nslookup("annotationhub.bioconductor.org", error=FALSE))
     } else {
         connect <- TRUE
-        message("Cannot determine internet connection.",
-                "\n If you experience connection issues consider ",
+        message("Assuming valid proxy connection through '", proxy, "'",
+                "\n  If you experience connection issues consider ",
                 "using 'localHub=TRUE'")
     }
     if (!connect && !localHub){
-        message("No internet connection using 'localHub=TRUE'")
+        message("Cannot connect to AnnotationHub server, using 'localHub=TRUE' instead")
         localHub <- !connect
     }
-    .Hub("AnnotationHub", hub, cache, proxy, localHub, ...)
+    .Hub("AnnotationHub", hub, cache, proxy, localHub, ask, ...)
 }
 
 
@@ -38,26 +39,15 @@ AnnotationHub <-
 ###
 
 setMethod("cache", "AnnotationHub",
-    function(x, ..., force=FALSE, verbose=FALSE) {
-        callNextMethod(x,
-                       cache.root="AnnotationHub", 
-                       cache.fun=setAnnotationHubOption, 
-                       proxy=getAnnotationHubOption("PROXY"), 
-                       max.downloads=getAnnotationHubOption("MAX_DOWNLOADS"),
-                       force=force,
-                       verbose=verbose)
-    }
-)
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### show method
-###
-
-setMethod("show", "AnnotationHub", function(object) 
+    function(x, ..., force=FALSE, verbose=FALSE)
 {
-    len <- length(object)
-    cat(sprintf("%s with %d record%s\n", class(object), len,
-                ifelse(len == 1L, "", "s")))
-    cat("# snapshotDate():", snapshotDate(object), "\n")
-    callNextMethod(object)
+    callNextMethod(
+        x,
+        cache.root="AnnotationHub",
+        cache.fun=setAnnotationHubOption,
+        proxy=getAnnotationHubOption("PROXY"),
+        max.downloads=getAnnotationHubOption("MAX_DOWNLOADS"),
+        force=force,
+        verbose=verbose
+    )
 })
